@@ -43,7 +43,7 @@ def generate_steps(nodes, edges):
 
 
 
-def generate_script(graph):
+def generate_script(steps_list):
     """
     Generate script for processing data.
     """
@@ -52,8 +52,8 @@ def generate_script(graph):
     file_loader = FileSystemLoader(filename)
     env = Environment(loader=file_loader)
     template = env.get_template("preprocess.j2")
-    node_map,edge_map = convert_graph(graph)
-    steps_list = generate_steps(node_map, edge_map)
+    # node_map,edge_map = convert_graph(graph)
+    # steps_list = generate_steps(node_map, edge_map)
     parameters = {
         "steps_list": steps_list
     }
